import Ajv from 'ajv';
import { replacePlaceholders } from '../../modules/utilities';

var ajv = new Ajv({
  allErrors: true,
  errorDataPath: 'property',
  removeAdditional: true,
  formats: {
    slug: '^[a-z0-9]+(?:-[a-z0-9]+)*$'
  }
});

var errorMessages = {
  format: {
    slug: 'This field may only contain letters, numbers and dashes'
  },
  maxLength: 'Maximum number of characters — :limit',
  minLength: 'Minimum number of characters — :limit',
  required: 'This field is required'
};

function resolveErrorMessage(error) {
  var keyword = error.keyword;
  var definedMessage = errorMessages[keyword];
  var keywordParam = error.params[keyword];

  if (definedMessage && (typeof definedMessage === 'string' || definedMessage[keywordParam])) {
    return replacePlaceholders(definedMessage[keywordParam] || definedMessage, error.params);
  }

  return error.message;
}

export default function validate(schema, data) {
  var errors = {};
  var valid = ajv.validate(schema, data);

  if (!valid) {
    ajv.errors.forEach(function (error) {
      var field = error.dataPath.replace('.', '');

      if (!errors[field]) {
        errors[field] = resolveErrorMessage(error);
      }
    });
  }

  return errors;
}