'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = validate;

var _ajv = require('ajv');

var _ajv2 = _interopRequireDefault(_ajv);

var _utilities = require('../../modules/utilities');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ajv = new _ajv2.default({
  allErrors: true,
  errorDataPath: 'property',
  removeAdditional: true,
  formats: {
    slug: '^[a-z0-9]+(?:-[a-z0-9]+)*$'
  }
});

var errorMessages = {
  format: {
    slug: 'This field may only contain letters, numbers and dashes'
  },
  maxLength: 'Maximum number of characters — :limit',
  minLength: 'Minimum number of characters — :limit',
  required: 'This field is required'
};

function resolveErrorMessage(error) {
  var keyword = error.keyword;
  var definedMessage = errorMessages[keyword];
  var keywordParam = error.params[keyword];

  if (definedMessage && (typeof definedMessage === 'string' || definedMessage[keywordParam])) {
    return (0, _utilities.replacePlaceholders)(definedMessage[keywordParam] || definedMessage, error.params);
  }

  return error.message;
}

function validate(schema, data) {
  var errors = {};
  var valid = ajv.validate(schema, data);

  if (!valid) {
    ajv.errors.forEach(function (error) {
      var field = error.dataPath.replace('.', '');

      if (!errors[field]) {
        errors[field] = resolveErrorMessage(error);
      }
    });
  }

  return errors;
}