'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addNotification = addNotification;
exports.addSuccessNotification = addSuccessNotification;
exports.addWarningNotification = addWarningNotification;
exports.addDangerNotification = addDangerNotification;
exports.removeNotification = removeNotification;
exports.removeAllNotifications = removeAllNotifications;
exports.notificationsReducer = notificationsReducer;

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var NOTIFICATIONS_ADD = 'NOTIFICATIONS_ADD';
var NOTIFICATIONS_REMOVE = 'NOTIFICATIONS_REMOVE';
var NOTIFICATIONS_REMOVE_ALL = 'NOTIFICATIONS_REMOVE_ALL';

var initialState = [];
var nextNotificationId = 0;

// Actions
function addNotification(message) {
  var kind = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'success';

  nextNotificationId += 1;

  return {
    type: NOTIFICATIONS_ADD,
    payload: {
      id: nextNotificationId,
      message: message,
      kind: kind
    }
  };
}

function addSuccessNotification(message) {
  return addNotification(message, 'success');
}

function addWarningNotification(message) {
  return addNotification(message, 'warning');
}

function addDangerNotification(message) {
  return addNotification(message, 'danger');
}

function removeNotification(id) {
  return {
    type: NOTIFICATIONS_REMOVE,
    id: id
  };
}

function removeAllNotifications() {
  return {
    type: NOTIFICATIONS_REMOVE_ALL
  };
}

// Reducer
function notificationsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case NOTIFICATIONS_ADD:
      return [].concat(_toConsumableArray(state), [action.payload]);
    case NOTIFICATIONS_REMOVE:
      return state.filter(function (notification) {
        return notification.id !== action.id;
      });
    case NOTIFICATIONS_REMOVE_ALL:
      return initialState;
    default:
      return state;
  }
}